# Steganography_in_text

## Скрывайте свои тайны удобно!!!

------

<ul>
<li>
<a href="#Crypter">Работа с шифратором</a>
<ul>
<li>
<a href="">Работа с шифратором</a>
</li>
<li>
<a href="">Работа с шифратором</a>
</li>
<li>
<a href="">Работа с шифратором</a>
</li>
</ul>
</li>
</ul>



-----

<br>
<br>
<br>
<br>
<br><br>
<br>
<br>
<br>
<br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br><br>

<h3 id="Crypter" style="color:rgb(104, 185, 255)">Шифратор</h3>
<p style="white-space:pre-wrap;">
# Для начала мы создадим объект 
</p>






